@@ -287,10 +287,6 @@
         <source>Unable to open report file!</source>
         <translation type="unfinished">Não foi possível abrir o Relatório!</translation>
     </message>
-    <message>
-        <source>invalid SQL or failed DB connection:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Music Summary</source>
         <translation type="unfinished"></translation>
@@ -335,6 +331,82 @@
         <source>Music Playout</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Main Log Output 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Log Output 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel First Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aux Log 1 Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aux Log 2 Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel Second Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel Third Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel Fourth Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audition/Cue Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel Fifth and Later Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>invalid SQL or failed DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished">Todos</translation>
+    </message>
+    <message>
+        <source>Relative</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NaturalLog Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LiveAssist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previous</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -723,6 +795,52 @@ Cor</translation>
         <source>Importing</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDCueEdit</name>
+    <message>
+        <source>&amp;Audition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Pause</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Stop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Fim</translation>
+    </message>
+</context>
+<context>
+    <name>RDCueEditDialog</name>
+    <message>
+        <source>Set Cue Point</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Cancelar</translation>
+    </message>
 </context>
 <context>
     <name>RDCutDialog</name>
@@ -1784,6 +1902,13 @@ Por Favor, cheque suas configurações e tenbte outra vez.</translation>
         <translation type="obsolete">Busca</translation>
     </message>
 </context>
+<context>
+    <name>RDPanelButton</name>
+    <message>
+        <source>No Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDPasswd</name>
     <message>
