@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsimpleplayer.cpp,v 1.11 2008/07/18 20:06:10 fredg Exp $
+//      $Id: rdsimpleplayer.cpp,v 1.14 2010/07/29 19:32:34 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -96,6 +96,12 @@ RDTransportButton *RDSimplePlayer::stopButton() const
 
 
 void RDSimplePlayer::play()
+{
+  play(0);
+}
+
+
+void RDSimplePlayer::play(int start_pos)
 {
   int handle=0;
   int play_cut_gain=0;
@@ -124,14 +130,12 @@ void RDSimplePlayer::play()
     for(int i=0;i<RD_MAX_PORTS;i++) {
       play_cae->setOutputVolume(play_card,play_stream,i,RD_MUTE_DEPTH);
     }
-    play_cae->
-      setOutputVolume(play_card,play_stream,play_port,0+play_cut_gain);
-    play_cae->positionPlay(play_handles.back(),q->value(1).toUInt());
-    play_cae->
-      play(play_handles.back(),q->value(2).toUInt()-q->value(1).toUInt(),
+    play_cae->setOutputVolume(play_card,play_stream,play_port,0+play_cut_gain);
+    play_cae->positionPlay(play_handles.back(),q->value(1).toUInt()+start_pos);
+    play_cae->play(play_handles.back(),
+		   q->value(2).toUInt()-(q->value(1).toUInt()+start_pos),
 		   RD_TIMESCALE_DIVISOR,false);
-    play_cae->
-      setPlayPortActive(play_card,play_port,play_stream);
+    play_cae->setPlayPortActive(play_card,play_port,play_stream);
   }
   delete q;
 }
@@ -158,6 +162,7 @@ void RDSimplePlayer::playingData(int handle)
   play_start_button->on();
   play_stop_button->off();
   play_is_playing=true;
+  emit played();
 }
 
 
@@ -175,4 +180,5 @@ void RDSimplePlayer::playStoppedData(int handle)
   play_stop_button->on();
   play_handles.pop();
   play_is_playing=false;
+  emit stopped();
 }
