@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsvc.cpp,v 1.71.8.2 2013/01/14 16:35:58 cvs Exp $
+//      $Id: rdsvc.cpp,v 1.71.8.10 2014/01/10 15:58:28 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,6 +31,7 @@
 #include <rdlog.h>
 #include <rddb.h>
 #include <rdescape_string.h>
+#include <rdweb.h>
 
 //
 // Global Classes
@@ -93,6 +94,19 @@ void RDSvc::setNameTemplate(const QString &str) const
 }
 
 
+QString RDSvc::descriptionTemplate() const
+{
+  return RDGetSqlValue("SERVICES","NAME",svc_name,"DESCRIPTION_TEMPLATE").
+    toString();
+}
+
+
+void RDSvc::setDescriptionTemplate(const QString &str) const
+{
+  SetRow("DESCRIPTION_TEMPLATE",str);
+}
+
+
 QString RDSvc::trackGroup() const
 {
   return RDGetSqlValue("SERVICES","NAME",svc_name,"TRACK_GROUP").
@@ -340,9 +354,9 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
   char buf[RD_MAX_IMPORT_LINE_LENGTH];
   QString str_buf;
   char var_buf[RD_MAX_IMPORT_LINE_LENGTH];
-  QString hours_buf;
-  QString minutes_buf;
-  QString seconds_buf;
+  int start_hour;
+  int start_minutes;
+  int start_seconds;
   QString hours_len_buf;
   QString minutes_len_buf;
   QString seconds_len_buf;
@@ -355,6 +369,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
   QString os_flag;
   int cartlen;
   QString sql;
+  bool ok=false;
 
   //
   // Set Import Source
@@ -402,6 +417,13 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
   QString preimport_cmd=q->value(3).toString();
   delete q;
 
+  //
+  // Open Source File
+  //
+  if((infile=fopen(RDDateDecode(infilename,date),"r"))==NULL) {
+    return false;
+  }
+
   //
   // Run Preimport Command
   //
@@ -501,9 +523,11 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
   //
   // Setup Data Source and Destination
   //
+  /*
   if((infile=fopen(RDDateDecode(infilename,date),"r"))==NULL) {
     return false;
   }
+  */
   sql=QString().sprintf("drop table `%s`",(const char *)dest_table);
   QSqlQuery *qq;          // Use QSqlQuery so we don't generate a 
   qq=new QSqlQuery(sql);  // spurious error message.
@@ -552,12 +576,14 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
       var_buf[cart_length]=0;
       cartname=QString(var_buf).stripWhiteSpace();
       if(strlen(buf)>=hours_size) {           // Get Start Hours
-	hours_buf=QString(buf).mid(hours_offset,hours_length);
-	if(strlen(buf)>=minutes_size) {           // Get Start Minutes
-	  minutes_buf=QString(buf).mid(minutes_offset,minutes_length);
-	  if(strlen(buf)>=seconds_size) {           // Get Start Seconds
-	    seconds_buf=QString(buf).mid(seconds_offset,seconds_length);
-	    if(strlen(buf)>=hours_len_size) {           // Get Length Hours
+	start_hour=QString(buf).mid(hours_offset,hours_length).toInt(&ok);
+	if(ok&&(strlen(buf)>=minutes_size)) {           // Get Start Minutes
+	  start_minutes=
+	    QString(buf).mid(minutes_offset,minutes_length).toInt(&ok);
+	  if(ok&&(strlen(buf)>=seconds_size)) {           // Get Start Seconds
+	    start_seconds=
+	      QString(buf).mid(seconds_offset,seconds_length).toInt(&ok);
+	    if(ok&&(strlen(buf)>=hours_len_size)) {     // Get Length Hours
 	      hours_len_buf=
 		QString(buf).mid(hours_len_offset,hours_len_length);
 	      if(strlen(buf)>=minutes_len_size) {       // Get Length Minutes
@@ -596,15 +622,15 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 			     ((!track_cart.isEmpty())&&
 			      (cartname==track_cart))) {
 			    sql=QString().sprintf("insert into `%s` \
-                                  set ID=%d,START_HOUR=%s,START_SECS=%d,\
+                                  set ID=%d,START_HOUR=%d,START_SECS=%d,\
                                   CART_NUMBER=%u,TITLE=\"%s\",LENGTH=%d,\
                                   EXT_DATA=\"%s\",EXT_EVENT_ID=\"%s\",\
                                   EXT_ANNC_TYPE=\"%s\",EXT_CART_NAME=\"%s\"",
 						  (const char *)dest_table,
 						  line_id++,
-						  (const char *)hours_buf,
-						  60*minutes_buf.toInt()+
-						  seconds_buf.toInt(),
+						  start_hour,
+						  60*start_minutes+
+						  start_seconds,
 						  cartnum,
 						  (const char *)
 						  RDEscapeString(title),
@@ -690,7 +716,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 	    break_first=true;
 	    insert_found=true;
 	  }
-	  q=new RDSqlQuery(sql);
+	  //	  q=new RDSqlQuery(sql);
 	}
       }
       if(!track_str.isEmpty()) {
@@ -701,7 +727,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 	    track_first=true;
 	    insert_found=true;
 	  }
-	  q=new RDSqlQuery(sql);
+	  //	  q=new RDSqlQuery(sql);
 	}
       }
     }
@@ -744,12 +770,12 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
   if(q->first()) {   // Already Exists
     delete q;
     sql=QString().sprintf("update LOGS set SERVICE=\"%s\",\
-                           DESCRIPTION=\"%s log\",ORIGIN_USER=\"%s\",\
+                           DESCRIPTION=\"%s\",ORIGIN_USER=\"%s\",\
                            ORIGIN_DATETIME=now(),LINK_DATETIME=now(),\
                            MODIFIED_DATETIME=now(),START_DATE=null,\
                            END_DATE=null,NEXT_ID=0",
 			  (const char *)RDEscapeString(svc_name),
-			  (const char *)RDEscapeString(svc_name),
+			  (const char *)RDEscapeString(RDDateDecode(descriptionTemplate(),date)),
 			  "RDLogManager");
     if(!purge_date.isEmpty()) {
       sql+=(",PURGE_DATE=\""+purge_date+"\"");
@@ -765,13 +791,14 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
   else {             // Doesn't exist
     delete q;
     sql=QString().sprintf("insert into LOGS set NAME=\"%s\",\
-                           SERVICE=\"%s\",DESCRIPTION=\"%s log\",\
+                           SERVICE=\"%s\",DESCRIPTION=\"%s\",\
                            ORIGIN_USER=\"%s\",ORIGIN_DATETIME=now(),\
                            LINK_DATETIME=now(),MODIFIED_DATETIME=now(),\
                            PURGE_DATE=\"%s\"",
 			  (const char *)RDEscapeString(logname),
 			  (const char *)RDEscapeString(svc_name),
-			  (const char *)RDEscapeString(logname),"RDLogManager",
+			  (const char *)RDEscapeString(RDDateDecode(descriptionTemplate(),date)),
+			  "RDLogManager",
 			  (const char *)purge_date);
     q=new RDSqlQuery(sql);
     delete q;
@@ -869,7 +896,9 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
 			(const char *)RDEscapeStringSQLColumn(svc_name),
 			(const char *)date.toString("yyyyMMdd"));
   import_name.replace(" ","_");
-  import(src,date,breakString(),trackString(src),import_name);
+  if(!import(src,date,breakString(),trackString(src),import_name)) {
+    return false;
+  }
 
   //
   // Calculate Source
@@ -991,7 +1020,7 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
   q=new RDSqlQuery(sql);
   delete q;
 
-  return false;
+  return true;
 }
 
 
@@ -1065,7 +1094,8 @@ void RDSvc::create(const QString exemplar) const
   if(exemplar.isEmpty()) {  // Create Empty Service
     sql=QString("insert into SERVICES set NAME=\"")+
       RDEscapeString(svc_name)+"\","+
-      "NAME_TEMPLATE=\""+RDEscapeString(svc_name)+"-%m%d\"";
+      "NAME_TEMPLATE=\""+RDEscapeString(svc_name)+"-%m%d\","+
+      "DESCRIPTION_TEMPLATE=\""+RDEscapeString(svc_name)+" log for %d/%m/%Y\"";
     q=new RDSqlQuery(sql);
     delete q;
 
@@ -1102,7 +1132,8 @@ void RDSvc::create(const QString exemplar) const
     delete q;
   }
   else {    // Base on Existing Service
-    sql=QString().sprintf("select NAME_TEMPLATE,CHAIN_LOG,AUTO_REFRESH,\
+    sql=QString().sprintf("select NAME_TEMPLATE,DESCRIPTION_TEMPLATE,\
+                           CHAIN_LOG,AUTO_REFRESH,\
                            ELR_SHELFLIFE,TFC_PATH,TFC_WIN_PATH,\
                            TFC_CART_OFFSET,TFC_CART_LENGTH,\
                            TFC_START_OFFSET,TFC_START_LENGTH,\
@@ -1132,7 +1163,9 @@ void RDSvc::create(const QString exemplar) const
     q=new RDSqlQuery(sql);
     if(q->first()) {
       sql=QString().sprintf("insert into SERVICES set\
-                             NAME_TEMPLATE=\"%s\",CHAIN_LOG=\"%s\",\
+                             NAME_TEMPLATE=\"%s\",\
+                             DESCRIPTION_TEMPLATE=\"%s\",\
+                             CHAIN_LOG=\"%s\",\
                              AUTO_REFRESH=\"%s\",ELR_SHELFLIFE=%d,\
                              TFC_PATH=\"%s\",TFC_WIN_PATH=\"%s\",\
                              TFC_CART_OFFSET=%d,TFC_CART_LENGTH=%d,\
@@ -1157,12 +1190,13 @@ void RDSvc::create(const QString exemplar) const
                              NAME=\"%s\",",
 			    (const char *)
 			    RDEscapeString(q->value(0).toString()),
-			    (const char *)q->value(1).toString(),
+			    (const char *)
+			    RDEscapeString(q->value(1).toString()),
 			    (const char *)q->value(2).toString(),
-                            q->value(3).toInt(),
-			    (const char *)q->value(4).toString(),
+			    (const char *)q->value(3).toString(),
+                            q->value(4).toInt(),
 			    (const char *)q->value(5).toString(),
-			    q->value(6).toInt(),
+			    (const char *)q->value(6).toString(),
 			    q->value(7).toInt(),
 			    q->value(8).toInt(),
 			    q->value(9).toInt(),
@@ -1180,9 +1214,9 @@ void RDSvc::create(const QString exemplar) const
 			    q->value(21).toInt(),
 			    q->value(22).toInt(),
 			    q->value(23).toInt(),
-			    (const char *)q->value(24).toString(),
+			    q->value(24).toInt(),
 			    (const char *)q->value(25).toString(),
-			    q->value(26).toInt(),
+			    (const char *)q->value(26).toString(),
 			    q->value(27).toInt(),
 			    q->value(28).toInt(),
 			    q->value(29).toInt(),
@@ -1200,10 +1234,11 @@ void RDSvc::create(const QString exemplar) const
 			    q->value(41).toInt(),
 			    q->value(42).toInt(),
 			    q->value(43).toInt(),
+			    q->value(44).toInt(),
 			    (const char *)RDEscapeString(svc_name));
       for(int i=0;i<168;i++) {
 	sql+=QString().sprintf("CLOCK%d=\"%s\",",
-			      i,(const char *)q->value(44+i).toString());
+			      i,(const char *)q->value(45+i).toString());
       }
       sql=sql.left(sql.length()-1);
       q=new RDSqlQuery(sql);
@@ -1376,17 +1411,39 @@ void RDSvc::remove() const
   q=new RDSqlQuery(sql);
   delete q;
 
-  sql=QString().sprintf("drop table %s_STACK",(const char *)tablename);
+  sql=QString().sprintf("drop table `%s_STACK`",(const char *)tablename);
   q=new RDSqlQuery(sql);
   delete q;
 
   sql=QString().sprintf("delete from LOGS where SERVICE=\"%s\"",
-			(const char *)svc_name);
+			(const char *)RDEscapeString(svc_name));
   q=new RDSqlQuery(sql);
   delete q;
 }
 
 
+QString RDSvc::xml() const
+{
+  QString sql;
+  RDSqlQuery *q;
+  QString ret;
+#ifndef WIN32
+  sql="select DESCRIPTION from SERVICES where NAME=\""+
+    RDEscapeString(svc_name)+"\"";
+
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    ret+="  <service>\n";
+    ret+="   "+RDXmlField("name",svc_name);
+    ret+="   "+RDXmlField("description",q->value(0).toString());
+    ret+="  </service>\n";
+  }
+  delete q;
+#endif  // WIN32
+  return ret;
+}
+
+
 QString RDSvc::timeString(int hour,int secs)
 {
   return QString().sprintf("%02d:%02d:%02d",hour,secs/60,secs%60);
