@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_decks.h,v 1.12 2007/02/21 17:24:28 fredg Exp $
+//      $Id: edit_decks.h,v 1.15.6.1 2012/11/28 18:49:36 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -40,7 +40,8 @@ class EditDecks : public QDialog
 {
   Q_OBJECT
   public:
-   EditDecks(RDStation *station,QWidget *parent=0,const char *name=0);
+  EditDecks(RDStation *station,RDStation *cae_station,
+	    QWidget *parent=0,const char *name=0);
    ~EditDecks();
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
@@ -74,14 +75,12 @@ class EditDecks : public QDialog
    QComboBox *edit_play_deck_box;
    RDCardSelector *edit_record_selector;
    RDCardSelector *edit_play_selector;
-   RDCardSelector *edit_audition_selector;
    QLabel *edit_monitor_label;
    QSpinBox *edit_monitor_box;
    QLabel *edit_default_on_label;
    QComboBox *edit_default_on_box;
    QComboBox *edit_format_box;
    QComboBox *edit_channels_box;
-   QComboBox *edit_samprate_box;
    QLabel *edit_bitrate_label;
    QComboBox *edit_bitrate_box;
    QLabel *edit_swstation_label;
