@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: opendb.cpp,v 1.38 2012/01/12 16:24:50 cvs Exp $
+//      $Id: opendb.cpp,v 1.38.4.1 2013/11/13 00:12:54 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -149,8 +149,8 @@ QString format_remote_host(const char *hostname) {
 }
 
 
-bool OpenDb(QString dbname,QString login,QString pwd,QString host,
-	    QString stationname,bool interactive)
+bool OpenDb(QString dbname,QString login,QString pwd,
+	    QString host,QString stationname,bool interactive)
 {
   // 
   // Yeesh, this whole method really needs a rewrite!
