@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: log_traffic.cpp,v 1.16 2007/10/04 20:53:32 dmills Exp $
+//      $Id: log_traffic.cpp,v 1.20.8.2 2013/03/09 00:21:16 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,6 +24,8 @@
 
 #include <rdconf.h>
 #include <rddb.h>
+#include <rdescape_string.h>
+
 #include <log_traffic.h>
 #include <globals.h>
 
@@ -44,7 +46,7 @@ void LogTraffic(const QString &svcname,const QString &logname,
   if((logline==NULL)||(svcname.isEmpty())) {
     return;
   }
-  QString svctablename=svcname;
+  QString svctablename=RDEscapeStringSQLColumn(svcname);
   svctablename.replace(" ","_");
   sql=QString().sprintf("insert into `%s_SRT` set\
                          LENGTH=%d,LOG_NAME=\"%s\",LOG_ID=%d,CART_NUMBER=%u,\
@@ -55,13 +57,14 @@ void LogTraffic(const QString &svcname,const QString &logname,
                          EXT_CART_NAME=\"%s\",TITLE=\"%s\",ARTIST=\"%s\",\
                          SCHEDULED_TIME=\"%s\",ISRC=\"%s\",PUBLISHER=\"%s\",\
                          COMPOSER=\"%s\",USAGE_CODE=%d,START_SOURCE=%d,\
-                         ONAIR_FLAG=\"%s\",ALBUM=\"%s\",LABEL=\"%s\"",
+                         ONAIR_FLAG=\"%s\",ALBUM=\"%s\",LABEL=\"%s\",\
+                         ISCI=\"%s\"",
 			(const char *)svctablename,
 			length,
-			(const char *)logname,
+			(const char *)RDEscapeString(logname),
 			logline->id(),
 			logline->cartNumber(),
-			(const char *)rdstation_conf->name(),
+			(const char *)RDEscapeString(rdstation_conf->name()),
 			(const char *)datetime.toString("yyyy-MM-dd"),
 			(const char *)logline->startTime(RDLogLine::Actual).
 			toString("hh:mm:ss"),
@@ -70,24 +73,25 @@ void LogTraffic(const QString &svcname,const QString &logname,
 			(const char *)logline->extStartTime().
 			toString("hh:mm:ss"),
 			logline->extLength(),
-			(const char *)logline->extData(),
-			(const char *)logline->extEventId(),
-			(const char *)logline->extAnncType(),
+			(const char *)RDEscapeString(logline->extData()),
+			(const char *)RDEscapeString(logline->extEventId()),
+			(const char *)RDEscapeString(logline->extAnncType()),
 			src,
 			logline->cutNumber(),
-			(const char *)logline->extCartName(),
-			(const char *)logline->title(),
-			(const char *)logline->artist(),
+			(const char *)RDEscapeString(logline->extCartName()),
+			(const char *)RDEscapeString(logline->title()),
+			(const char *)RDEscapeString(logline->artist()),
 			(const char *)logline->startTime(RDLogLine::Logged).
 			toString("hh:mm:ss"),
 			(const char *)logline->isrc(),
-			(const char *)logline->publisher(),
-			(const char *)logline->composer(),
+			(const char *)RDEscapeString(logline->publisher()),
+			(const char *)RDEscapeString(logline->composer()),
 			logline->usageCode(),
 			logline->startSource(),
 			(const char *)RDYesNo(onair_flag),
-			(const char *)logline->album(),
-			(const char *)logline->label());
+			(const char *)RDEscapeString(logline->album()),
+			(const char *)RDEscapeString(logline->label()),
+			(const char *)RDEscapeString(logline->isci()));
   q=new RDSqlQuery(sql);
   delete q;
 }
