@@ -51,19 +51,19 @@
     </message>
     <message>
         <source>&amp;Audition</source>
-        <translation>&amp;Lytt</translation>
+        <translation type="obsolete">&amp;Lytt</translation>
     </message>
     <message>
         <source>&amp;Pause</source>
-        <translation>&amp;Pause</translation>
+        <translation type="obsolete">&amp;Pause</translation>
     </message>
     <message>
         <source>&amp;Stop</source>
-        <translation>&amp;Stopp</translation>
+        <translation type="obsolete">&amp;Stopp</translation>
     </message>
     <message>
         <source>Start</source>
-        <translation>Start</translation>
+        <translation type="obsolete">Start</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -75,24 +75,20 @@
     </message>
     <message>
         <source>Edit Marker</source>
-        <translation>Rediger markør</translation>
+        <translation type="unfinished">Rediger markør</translation>
     </message>
     <message>
         <source>Edit Track</source>
-        <translation>Rediger spor</translation>
+        <translation type="unfinished">Rediger spor</translation>
     </message>
     <message>
         <source>Edit Log Track</source>
-        <translation>Rediger loggspor</translation>
+        <translation type="unfinished">Rediger loggspor</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
         <translation>Overtoning viss førre korga endar før</translation>
     </message>
-    <message>
-        <source>End</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Duplicate Start Time</source>
         <translation type="unfinished"></translation>
@@ -101,6 +97,10 @@
         <source>An event is already scheduled with this start time!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Recue</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HourSelector</name>
@@ -399,6 +399,10 @@ Tail</source>
         <source>Selected:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>ALBUM</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListLogs</name>
@@ -607,7 +611,7 @@ LASTAR PÅ NYTT</translation>
     <name>ModeDisplay</name>
     <message>
         <source>Operating Mode</source>
-        <translation>Køyremodus</translation>
+        <translation type="unfinished">Køyremodus</translation>
     </message>
     <message>
         <source>LiveAssist</source>
@@ -621,6 +625,14 @@ LASTAR PÅ NYTT</translation>
         <source>Manual</source>
         <translation>Manuelt</translation>
     </message>
+    <message>
+        <source>Aux1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aux2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PostCounter</name>
