@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: audio_cart.cpp,v 1.50.2.1 2010/02/09 21:43:53 cvs Exp $
+//      $Id: audio_cart.cpp,v 1.57.6.9 2014/01/21 21:18:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,7 +20,7 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qbitmap.h>
+#include <qpixmap.h>
 #include <unistd.h>
 #include <qdialog.h>
 #include <qstring.h>
@@ -35,6 +35,7 @@
 #include <qbuttongroup.h>
 #include <qapplication.h>
 
+#include <rdcut.h>
 #include <rdcddbrecord.h>
 #include <rddb.h>
 #include <rdwavedata.h>
@@ -55,7 +56,8 @@ bool import_active=false;
 
 
 AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
-		     bool select_cut,QWidget *parent,const char *name)
+		     bool select_cut,bool profile_rip,
+		     QWidget *parent,const char *name)
   : QWidget(parent,name)
 {
   rdcart_import_metadata=true;
@@ -63,6 +65,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   rdcart_cart=cart;
   rdcart_import_path=path;
   rdcart_select_cut=select_cut;
+  rdcart_profile_rip=profile_rip;
   rdcart_modification_allowed=lib_user->editAudio()&&cart->owner().isEmpty();
 
   setCaption(QString().sprintf("%u",rdcart_cart->number())+" - "+
@@ -127,6 +130,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   rdcart_cut_list=new RDListView(this,"rdcart_cut_list");
   rdcart_cut_list->setGeometry(100,0,430,sizeHint().height());
   rdcart_cut_list->setAllColumnsShowFocus(true);
+  rdcart_cut_list->setSelectionMode(QListView::Extended);
   rdcart_cut_list->setItemMargin(5);
   rdcart_cut_list->setSorting(11);
   connect(rdcart_cut_list,
@@ -181,10 +185,10 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   // Record Cut Button
   //
-  QBitmap *pix=new QBitmap(QSize(80,50));
+  QPixmap *pix=new QPixmap(QSize(80,50));
   QPainter *p=new QPainter(pix);
   QFontMetrics *m=new QFontMetrics(button_font);
-  p->eraseRect(0,0,80,50);
+  p->fillRect(0,0,80,50,palette().color(QPalette::Active,QColorGroup::Button));
   p->setPen(QColor(color1));
   p->setFont(button_font);
   p->drawText((80-m->width(tr("Cut Info")))/2,20,tr("Cut Info"));
@@ -228,7 +232,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   p=new QPainter(pix);
   m=new QFontMetrics(button_font);
-  p->eraseRect(0,0,80,50);
+  p->fillRect(0,0,80,50,palette().color(QPalette::Active,QColorGroup::Button));
   p->setPen(QColor(color1));
   p->setFont(button_font);
   p->drawText((80-m->width(tr("Import")))/2,20,tr("Import"));
@@ -278,14 +282,16 @@ QSizePolicy AudioCart::sizePolicy() const
 
 void AudioCart::addCutData()
 {
-  QString next_name=QString().
-    sprintf("%06d_%03d",
-	    rdcart_cart->number(),
-	    rdcart_cart->addCut(rdlibrary_conf->defaultFormat(),
-				rdlibrary_conf->
-				defaultSampleRate(),
-				rdlibrary_conf->defaultBitrate(),
-				rdlibrary_conf->defaultChannels()));
+  QString next_name=RDCut::cutName(rdcart_cart->number(),
+		 rdcart_cart->addCut(rdlibrary_conf->defaultFormat(),
+				     rdlibrary_conf->defaultBitrate(),
+				     rdlibrary_conf->defaultChannels()));
+  if(next_name.isEmpty()) {
+    QMessageBox::warning(this,tr("RDLibrary - Edit Cart"),
+			 tr("This cart cannot contain any additional cuts!"));
+    return;
+  }
+  rdcart_cut_list->clearSelection();
   RDListViewItem *item=new RDListViewItem(rdcart_cut_list);
   item->setText(11,next_name);
   UpdateCutCount();
@@ -301,35 +307,63 @@ void AudioCart::deleteCutData()
 {
   QString filename;
   QString str;
-  QListViewItem *item=rdcart_cut_list->selectedItem();
-  if(item==NULL) {
+  std::vector<QString> cutnames;
+  RDListViewItem *item=NULL;
+
+  item=SelectedCuts(&cutnames);
+  if(cutnames.size()==0) {
     return;
   }
-  str=QString(tr("Are you sure you want to delete"));
-  switch(QMessageBox::question(this,tr("Delete Cut"),
-			      QString().
-			      sprintf("%s \"%s\"?",(const char *)str,
-				      (const char *)item->text(1)),
-			      QMessageBox::Yes,QMessageBox::No)) {
-      case QMessageBox::No:
-      case QMessageBox::NoButton:
-	return;
 
-      default:
-	break;
+  //
+  // Prompt for Deletion
+  //
+  if(cutnames.size()==1) {
+    str=QString(tr("Are you sure you want to delete"));
+    switch(QMessageBox::question(this,tr("Delete Cut"),
+				 QString().
+				 sprintf("%s \"%s\"?",(const char *)str,
+					 (const char *)item->text(1)),
+				 QMessageBox::Yes,QMessageBox::No)) {
+    case QMessageBox::No:
+    case QMessageBox::NoButton:
+      return;
+      
+    default:
+      break;
+    }
   }
-  QString sql=QString().sprintf("select CUT_NAME from RECORDINGS where \
-                                 CUT_NAME=\"%s\"",
-				(const char *)item->text(11));
-  RDSqlQuery *q=new RDSqlQuery(sql);
-  if(q->first()) {
-    if(QMessageBox::warning(this,tr("RDCatch Event Exists"),
-			    tr("This cut is used in one or more RDCatch events!\nDo you still want to delete it?"),QMessageBox::Yes,QMessageBox::No)==QMessageBox::No) {
-      delete q;
+  else {
+    if(QMessageBox::question(this,"RDLibrary - "+tr("Delete Cuts"),
+			     tr("Are you sure you want to delete")+
+			     QString().sprintf(" %lu ",cutnames.size())+
+			     tr("cuts")+"?",QMessageBox::Yes,
+			     QMessageBox::No)!=QMessageBox::Yes) {
       return;
     }
   }
-  delete q;
+
+  //
+  // Check for RDCatch Events
+  //
+  for(unsigned i=0;i<cutnames.size();i++) {
+    QString sql=QString().
+      sprintf("select CUT_NAME from RECORDINGS where CUT_NAME=\"%s\"",
+	      (const char *)cutnames[i]);
+    RDSqlQuery *q=new RDSqlQuery(sql);
+    if(q->first()) {
+      if(QMessageBox::warning(this,tr("RDCatch Event Exists"),
+			      tr("One or more cuts are used in one or more RDCatch events!\nDo you still want to delete?"),QMessageBox::Yes,QMessageBox::No)==QMessageBox::No) {
+	delete q;
+	return;
+      }
+    }
+    delete q;
+  }
+
+  //
+  // Check Clipboard
+  //
   if(cut_clipboard!=NULL) {
     if(item->text(11)==cut_clipboard->cutName()) {
       if(QMessageBox::question(this,tr("Empty Clipboard"),
@@ -342,40 +376,70 @@ void AudioCart::deleteCutData()
       paste_cut_button->setDisabled(true);
     }
   }
-  rdcart_cart->removeCut(item->text(11));
+
+  //
+  // Delete Cuts
+  //
+  for(unsigned i=0;i<cutnames.size();i++) {
+    if(!rdcart_cart->removeCut(rdstation_conf,lib_user,cutnames[i],
+			       lib_config)) {
+      QMessageBox::warning(this,tr("RDLibrary"),
+			   tr("Unable to delete audio for cut")+
+			   QString().sprintf(" %d!",RDCut::cutNumber(cutnames[i])));
+      return;
+    }
+  }
   UpdateCutCount();
-  QListViewItem *next_item=item->nextSibling();
-  if(next_item==NULL) {
-    next_item=rdcart_cut_list->lastItem();
-  }
-  if(next_item!=NULL) {
-    rdcart_cut_list->setSelected(next_item,true);
-  }
-  rdcart_cut_list->removeItem(item);
+
   rdcart_cart->updateLength(rdcart_controls->enforce_length_box->isChecked(),
 			    QTime().msecsTo(rdcart_controls->
 					    forced_length_edit->time()));
   rdcart_cart->resetRotation();
   disk_gauge->update();
+
+  //
+  // Update List
+  //
+  item=(RDListViewItem *)rdcart_cut_list->firstChild();
+  while(item!=NULL) {
+    RDListViewItem *del=NULL;
+    if(item->isSelected()) {
+      del=item;
+    }
+    item=(RDListViewItem *)item->nextSibling();
+    if(del!=NULL) {
+      delete del;
+    }
+  }
+
   emit cartDataChanged();
 }
 
 
 void AudioCart::copyCutData()
 {
-  if(rdcart_cut_list->currentItem()==0) {
+  std::vector<QString> cutnames;
+  RDListViewItem *item=NULL;
+
+  if((item=SelectedCuts(&cutnames))==NULL) {
+    QMessageBox::information(this,"RDLibrary - "+tr("Copy Cut"),
+			  tr("No data copied - you must select a single cut!"));
     return;
   }
   if(cut_clipboard!=NULL) {
     delete cut_clipboard;
   }
-  cut_clipboard=new RDCut(rdcart_cut_list->currentItem()->text(11));
+  cut_clipboard=new RDCut(item->text(11));
   paste_cut_button->setEnabled(rdcart_modification_allowed);
 }
 
+
 void AudioCart::extEditorCutData()
 {
-  if(rdcart_cut_list->currentItem()==0) {
+  std::vector<QString> cutnames;
+  RDListViewItem *item=NULL;
+
+  if((item=SelectedCuts(&cutnames))==NULL) {
     return;
   }
 
@@ -394,8 +458,12 @@ void AudioCart::extEditorCutData()
 
 void AudioCart::pasteCutData()
 {
-  QListViewItem *item=rdcart_cut_list->currentItem();
-  if(item==0) {
+  std::vector<QString> cutnames;
+  RDListViewItem *item=NULL;
+
+  if((item=SelectedCuts(&cutnames))==NULL) {
+    QMessageBox::information(this,"RDLibrary - "+tr("Paste Cut"),
+			  tr("You must select a single cut!"));
     return;
   }
   if(!cut_clipboard->exists()) {
@@ -415,7 +483,7 @@ void AudioCart::pasteCutData()
     }
   }
   cut_clipboard->connect(this,SLOT(copyProgressData(const QVariant &)));
-  cut_clipboard->copyTo(item->text(11));
+  cut_clipboard->copyTo(rdstation_conf,lib_user,item->text(11),lib_config);
   cut_clipboard->disconnect(this,SLOT(copyProgressData(const QVariant &)));
   rdcart_cart->updateLength(rdcart_controls->enforce_length_box->isChecked(),
 			    QTime().msecsTo(rdcart_controls->
@@ -429,19 +497,21 @@ void AudioCart::pasteCutData()
 
 void AudioCart::editCutData()
 {
-  RDListViewItem *item=(RDListViewItem *)rdcart_cut_list->selectedItem();
-
-  if(item==NULL) {
+  RDListViewItem *item=NULL;
+  std::vector<QString> cutnames;
+  if((item=SelectedCuts(&cutnames))==NULL) {
     return;
   }
   QString cutname=item->text(11);
   if(!RDAudioExists(cutname)) {
+    QMessageBox::information(this,"RDLibrary",
+			     tr("No audio is present in the cut!"));
     return;
   }
   RDEditAudio *edit=
-    new RDEditAudio(rdcart_cart,cutname,rdcae,lib_user,
-		    rdlibrary_conf->outputCard(),rdlibrary_conf->outputPort(),
-		    rdlibrary_conf->tailPreroll(),
+    new RDEditAudio(rdcart_cart,cutname,rdcae,lib_user,rdstation_conf,
+		    lib_config,rdlibrary_conf->outputCard(),
+		    rdlibrary_conf->outputPort(),rdlibrary_conf->tailPreroll(),
 		    rdlibrary_conf->trimThreshold(),this);
   if(edit->exec()!=-1) {
     emit cartDataChanged();
@@ -456,13 +526,12 @@ void AudioCart::editCutData()
 
 void AudioCart::recordCutData()
 {
-  QString cutname;
-  RDListViewItem *item=(RDListViewItem *)rdcart_cut_list->selectedItem();
-
-  if(item==NULL) {
+  RDListViewItem *item=NULL;
+  std::vector<QString> cutnames;
+  if((item=SelectedCuts(&cutnames))==NULL) {
     return;
   }
-  cutname=item->text(11);
+  QString cutname=item->text(11);
   RecordCut *cut=new RecordCut(rdcart_cart,cutname,this,"cut");
   cut->exec();
   delete cut;
@@ -482,25 +551,34 @@ void AudioCart::ripCutData()
 {
   int track;
   QString cutname;
-  RDListViewItem *item=(RDListViewItem *)rdcart_cut_list->selectedItem();
+  QString title;
+  QString artist;
+  QString album;
 
-  if(item==NULL) {
+  RDListViewItem *item=NULL;
+  std::vector<QString> cutnames;
+  if((item=SelectedCuts(&cutnames))==NULL) {
     return;
   }
   cutname=item->text(11);
   RDCddbRecord *rec=new RDCddbRecord();
-  CdRipper *ripper=new CdRipper(cutname,rec,rdlibrary_conf);
-  if((track=ripper->exec())>=0) {
-    if(rdcart_controls->title_edit->text().isEmpty()||
-       (rdcart_controls->title_edit->text()==tr("[new cart]"))) {
-      rdcart_controls->title_edit->setText(rec->trackTitle(track));
+  CdRipper *ripper=new CdRipper(cutname,rec,rdlibrary_conf,rdcart_profile_rip);
+  if((track=ripper->exec(&title,&artist,&album))>=0) {
+    if((rdcart_controls->title_edit->text().isEmpty()||
+	(rdcart_controls->title_edit->text()==tr("[new cart]")))&&
+       (!title.isEmpty())) {
+      rdcart_controls->title_edit->setText(title);
     }
+    rdcart_controls->artist_edit->setText(artist);
+    rdcart_controls->album_edit->setText(album);
+    /*
     if(rdcart_controls->artist_edit->text().isEmpty()) {
       rdcart_controls->artist_edit->setText(rec->discArtist());
     }
     if(rdcart_controls->album_edit->text().isEmpty()) {
       rdcart_controls->album_edit->setText(rec->discAlbum());
     }
+    */
     RDCut *cut=new RDCut(cutname);
     cut->setIsrc(rec->isrc(track));
     delete cut;
@@ -523,9 +601,9 @@ void AudioCart::importCutData()
 {
   QString cutname;
   RDWaveData wavedata;
-  RDListViewItem *item=(RDListViewItem *)rdcart_cut_list->selectedItem();
-
-  if(item==NULL) {
+  RDListViewItem *item=NULL;
+  std::vector<QString> cutnames;
+  if((item=SelectedCuts(&cutnames))==NULL) {
     return;
   }
   cutname=item->text(11);
@@ -534,8 +612,8 @@ void AudioCart::importCutData()
   RDImportAudio *import=new RDImportAudio(cutname,rdcart_import_path,
 					  &settings,&rdcart_import_metadata,
 					  &wavedata,cut_clipboard,
-					  rdstation_conf,&import_active,
-					  lib_config);
+					  rdstation_conf,lib_user,
+					  &import_active,lib_config);
   import->enableAutotrim(rdlibrary_conf->defaultTrimState());
   import->setAutotrimLevel(rdlibrary_conf->trimThreshold());
   import->enableNormalization(rdlibrary_conf->ripperLevel()!=0);
@@ -575,6 +653,9 @@ void AudioCart::importCutData()
     if(rdcart_controls->user_defined_edit->text().isEmpty()) {
       rdcart_controls->user_defined_edit->setText(wavedata.userDefined());
     }
+    RDCut *cut=new RDCut(cutname);
+    cut->setMetadata(&wavedata);
+    delete cut;
   }
   if(cut_clipboard==NULL) {
     paste_cut_button->setDisabled(true);
@@ -602,6 +683,24 @@ void AudioCart::copyProgressData(const QVariant &step)
 }
 
 
+RDListViewItem *AudioCart::SelectedCuts(std::vector<QString> *cutnames)
+{
+  RDListViewItem *ret=NULL;
+  RDListViewItem *item=(RDListViewItem *)rdcart_cut_list->firstChild();
+  while(item!=NULL) {
+    if(item->isSelected()) {
+      cutnames->push_back(item->text(11));
+      ret=item;
+    }
+    item=(RDListViewItem *)item->nextSibling();
+  }
+  if(cutnames->size()==1) {
+    return ret;
+  }
+  return NULL;
+}
+
+
 void AudioCart::RefreshList()
 {
   RDSqlQuery *q;
@@ -660,7 +759,7 @@ void AudioCart::RefreshList()
 	  err=true;
 	}
 	break;
-	
+
       case RDCart::AlwaysValid:
 	break;
       }
