@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary.h,v 1.43 2008-04-03 16:50:07 fredg Exp $
+//      $Id: rdlibrary.h,v 1.45.8.4 2014/01/21 19:12:42 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,17 +35,20 @@
 #include <qcheckbox.h>
 #include <qpixmap.h>
 #include <qprogressdialog.h>
+#include <qtimer.h>
 
-#include <rdinstancelock.h>
 #include <rdstation.h>
 #include <rdcart.h>
 #include <rduser.h>
 #include <rdripc.h>
 #include <rdlibrary_conf.h>
 #include <rdlistviewitem.h>
+
 #include <rdconfig.h>
 
+#include <lib_listview.h>
 #include <disk_gauge.h>
+#include <cart_tip.h>
 
 #define RDLIBRARY_GEOMETRY_FILE ".rdlibrary"
 #define RDLIBRARY_STEP_SIZE 5000
@@ -59,8 +62,9 @@
 #define RDLIBRARY_MAX_LENGTH_COLOR red
 #define RDLIBRARY_ENFORCE_LENGTH_COLOR blue
 
+#define RDLIBRARY_USAGE "[--profile-ripping]\n\n--profile-ripping\n     Print profiling information to stdout when performing rips from\n     optical media.\n\n"
 
-class MainWidget : public QDialog
+class MainWidget : public QWidget
 {
  Q_OBJECT
  public:
@@ -80,10 +84,13 @@ class MainWidget : public QDialog
   void deleteData();
   void ripData();
   void reportsData();
+  void cartOnItemData(QListViewItem *item);
   void cartClickedData(QListViewItem *item);
   void cartDoubleclickedData(QListViewItem *,const QPoint &,int);
   void audioChangedData(int state);
   void macroChangedData(int state);
+  void searchLimitChangedData(int state);
+  void dragsChangedData(int state);
   void quitMainWidget();
 
  protected:
@@ -100,7 +107,10 @@ class MainWidget : public QDialog
   QString GetTypeFilter();
   void LoadGeometry();
   void SaveGeometry();
-  RDListView *lib_cart_list;
+  void LockUser();
+  bool UnlockUser();
+  LibListView *lib_cart_list;
+  CartTip *lib_cart_tip;
   QString lib_filter_text;
   QString lib_search_text;
   QPixmap *lib_playout_map;
@@ -120,16 +130,25 @@ class MainWidget : public QDialog
   QPushButton *lib_rip_button;
   QPushButton *lib_reports_button;
   QPushButton *lib_close_button;
+  QCheckBox *lib_allowdrag_box;
+  QLabel *lib_allowdrag_label;
   QCheckBox *lib_showaudio_box;
   QLabel *lib_showaudio_label;
   QCheckBox *lib_showmacro_box;
+  QLabel *lib_shownotes_label;
+  QCheckBox *lib_shownotes_box;
+  QLabel *lib_showmatches_label;
+  QCheckBox *lib_showmatches_box;
   QLabel *lib_showmacro_label;
   QString lib_default_group;
   QString lib_import_path;
-  RDInstanceLock *lib_lock;
   QPixmap *lib_rivendell_map;
   RDStation::FilterMode lib_filter_mode;
   QProgressDialog *lib_progress_dialog;
+  bool profile_ripping;
+  bool lib_edit_pending;
+  bool lib_user_changed;
+  QTimer *lib_user_timer;
 };
 
 
