@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_grid.h,v 1.5 2007/02/14 21:57:04 fredg Exp $
+//      $Id: edit_grid.h,v 1.8.8.1 2013/10/11 17:16:49 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,7 +28,7 @@
 #include <qlabel.h>
 #include <qpopupmenu.h>
 
-#include <rpushbutton.h>
+#include <rdpushbutton.h>
 
 #include <rdlistview.h>
 #include <rdclock.h>
@@ -44,9 +44,11 @@ class EditGrid : public QDialog
 
  private slots:
   void hourButtonData(int id);
+  void allHourButtonData();
   void rightHourButtonData(int id,const QPoint &pt);
   void aboutToShowData();
   void editClockData();
+  void clearHourData();
   void closeData();
 
  protected:
@@ -59,7 +61,7 @@ class EditGrid : public QDialog
   QString GetClock(int dayofweek,int hour);
   QString edit_servicename;
   QString current_clockname;
-  RPushButton *edit_hour_button[7][24];
+  RDPushButton *edit_hour_button[7][24];
   QPopupMenu *edit_right_menu;
   int edit_rightclick_id;
 };
