@@ -590,6 +590,23 @@ un evento ya existente.</translation>
         <source>Clear Hour</source>
         <translation>Limpiar tortas</translation>
     </message>
+    <message>
+        <source>Change
+&amp;All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to update ALL clocks in the grid?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This operation cannot be undone!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -1237,7 +1254,11 @@ Reporte</translation>
     </message>
     <message>
         <source>Report complete!</source>
-        <translation>¡Reporte completado!</translation>
+        <translation type="obsolete">¡Reporte completado!</translation>
+    </message>
+    <message>
+        <source>Report generated in</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
