@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpanel.h,v 1.10 2007/12/31 18:49:12 fredg Exp $
+//      $Id: rdpanel.h,v 1.16.4.1 2013/12/30 21:11:59 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,6 +35,7 @@
 #include <rdconfig.h>
 #include <rdsound_panel.h>
 #include <rdevent_player.h>
+#include <rdemptycart.h>
 
 //
 // Settings
@@ -43,6 +44,7 @@
 #define METER_INTERVAL 50
 #define RDPANEL_PANEL_BUTTON_ROWS 7
 #define RDPANEL_PANEL_BUTTON_COLUMNS 9
+#define RDPANEL_USAGE "\n"
 
 class MainWidget : public QWidget
 {
@@ -75,6 +77,9 @@ class MainWidget : public QWidget
   QPixmap *lib_rivendell_map;
   QString panel_filter;
   QString panel_group;
+  QString panel_schedcode;
+  QPixmap *panel_skin_pixmap;
+  RDEmptyCart *panel_empty_cart;
 };
 
 
