@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: btacs82.cpp,v 1.9 2008-10-01 13:10:15 fredg Exp $
+//      $Id: btacs82.cpp,v 1.14 2010/08/03 23:39:25 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@
 
 
 BtAcs82::BtAcs82(RDMatrix *matrix,QObject *parent,const char *name)
-  : QObject(parent,name)
+  : Switcher(matrix,parent,name)
 {
   //
   // Initialize Data Structures
@@ -90,6 +90,36 @@ BtAcs82::~BtAcs82()
 }
 
 
+RDMatrix::Type BtAcs82::type()
+{
+  return RDMatrix::BtAcs82;
+}
+
+
+unsigned BtAcs82::gpiQuantity()
+{
+  return bt_gpis;
+}
+
+
+unsigned BtAcs82::gpoQuantity()
+{
+  return bt_gpos;
+}
+
+
+bool BtAcs82::primaryTtyActive()
+{
+  return true;
+}
+
+
+bool BtAcs82::secondaryTtyActive()
+{
+  return false;
+}
+
+
 void BtAcs82::processCommand(RDMacro *cmd)
 {
   char str[9];
