@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddbcheck.cpp,v 1.11.2.1 2009/08/17 13:54:26 cvs Exp $
+//      $Id: rddbcheck.cpp,v 1.18.4.1 2013/11/13 23:36:39 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,6 +39,8 @@
 #include <rdlog.h>
 #include <rdcreate_log.h>
 #include <rdescape_string.h>
+#include <rdwavefile.h>
+#include <dbversion.h>
 
 //
 // MAINTAINER'S NOTE
@@ -49,8 +51,12 @@
 MainObject::MainObject(QObject *parent,const char *name)
   :QObject(parent,name)
 {
+  bool skip_db_check=false;
+  unsigned schema=0;
+
   check_yes=false;
   check_no=false;
+  QString username="user";
 
   //
   // Read Command Options
@@ -58,6 +64,12 @@ MainObject::MainObject(QObject *parent,const char *name)
   RDCmdSwitch *cmd=
     new RDCmdSwitch(qApp->argc(),qApp->argv(),"rddbcheck",RDDBCHECK_USAGE);
   for(unsigned i=0;i<cmd->keys();i++) {
+    if(cmd->key(i)=="--skip-db-check") {
+      skip_db_check=true;
+    }
+    if(cmd->key(i)=="--user") {
+      username=cmd->value(i);
+    }
     if(cmd->key(i)=="--yes") {
       check_yes=true;
     }
@@ -116,12 +128,35 @@ MainObject::MainObject(QObject *parent,const char *name)
   // Open Database
   //
   QString err (tr("rddbcheck: "));
-  QSqlDatabase *db=RDInitDb (&err);
+  QSqlDatabase *db=RDInitDb(&schema,&err);
   if(!db) {
     fprintf(stderr,err.ascii());
     delete cmd;
     exit(256);
   }
+  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
+    fprintf(stderr,
+	    "rddbcheck: database version mismatch, should be %u, is %u\n",
+	    RD_VERSION_DATABASE,schema);
+    exit(256);
+  }
+
+  //
+  // Validate Station
+  //
+  check_station=new RDStation(rdconfig->stationName());
+  if(!check_station->exists()) {
+    fprintf(stderr,"rddbcheck: no such host [\"%s\"]\n",
+	    (const char *)rdconfig->stationName());
+  }  
+
+  //
+  // Validate User
+  //
+  check_user=new RDUser(username);
+  if(!check_user->exists()) {
+    fprintf(stderr,"rddbcheck: no such user [\"%s\"]\n",(const char *)username);
+  }
 
   if(!orphan_group_name.isEmpty()) {
     QString sql=QString().sprintf("select NAME from GROUPS where NAME=\"%s\"",
@@ -189,6 +224,13 @@ MainObject::MainObject(QObject *parent,const char *name)
   CheckOrphanedAudio();
   printf("done.\n\n");
 
+  //
+  // Validating Audio Lengths
+  //
+  printf("Validating audio lengths (this may take some time)...\n");
+  ValidateAudioLengths();
+  printf("done.\n\n");
+
   exit(0);
 }
 
@@ -201,7 +243,7 @@ void MainObject::CheckOrphanedTracks()
   QSqlQuery *q1;
 
   while(q->next()) {
-    logname=q->value(2).toString();
+    logname=q->value(2).toString()+"_LOG";
     logname.replace(" ","_");
     sql=QString().sprintf("select ID from %s where CART_NUMBER=%u",
 			  (const char *)logname,q->value(0).toUInt());
@@ -212,10 +254,12 @@ void MainObject::CheckOrphanedTracks()
       fflush(NULL);
       if(UserResponse()) {
 	RDCart *cart=new RDCart(q->value(0).toUInt());
-	cart->remove();
+	cart->remove(check_station,check_user,rdconfig);
 	delete cart;
 	RDLog *log=new RDLog(q->value(2).toString());
-	log->updateTracks();
+	if(log->exists()) {
+	  log->updateTracks();
+	}
 	delete log;
       }
     }
@@ -311,7 +355,7 @@ void MainObject::CheckEvents()
     //
     sql=QString().sprintf ("select ID from %s_PRE",(const char *)eventname);
     q1=new QSqlQuery(sql);
-    if(!q1->isActive()) {
+    if(q1->size()<0) {
       printf("  Event %s is missing the PRE table -- fix (y/N)? ",
 	     (const char *)q->value(0).toString());
       fflush(NULL);
@@ -591,6 +635,65 @@ void MainObject::CheckOrphanedAudio()
 }
 
 
+void MainObject::ValidateAudioLengths()
+{
+  QString sql;
+  QSqlQuery *q;
+  RDWaveFile *wave=NULL;
+
+  sql="select CUT_NAME,CART_NUMBER,LENGTH from CUTS order by CART_NUMBER";
+  q=new QSqlQuery(sql);
+  while(q->next()) {
+    if(q->value(2).toInt()>0) {
+      wave=new RDWaveFile(RDCut::pathName(q->value(0).toString()));
+      if(wave->openWave()) {
+	if((int)wave->getExtTimeLength()<(q->value(2).toInt()-100)) {
+	  SetCutLength(q->value(0).toString(),wave->getExtTimeLength());
+	}
+      }
+      else {
+	SetCutLength(q->value(0).toString(),0);
+      }
+      delete wave;
+    }
+  }
+  delete q;
+}
+
+
+void MainObject::SetCutLength(const QString &cutname,int len)
+{
+  QString sql;
+  QSqlQuery *q;
+  RDCut *cut=new RDCut(cutname);
+  RDCart *cart=new RDCart(cut->cartNumber());
+
+  printf("  Cut %d [%s] in cart %06u [%s] has invalid length.  Correct? (y/N) ",
+	 cut->cutNumber(),
+	 (const char *)cut->description(),
+	 cart->number(),
+	 (const char *)cart->title());
+  fflush(NULL);
+  if(UserResponse()) {
+    fflush(NULL);
+    sql=QString().sprintf("update CUTS set START_POINT=0,END_POINT=%d,\
+                           FADEUP_POINT=-1,FADEDOWN_POINT=-1,\
+                           SEGUE_START_POINT=-1,SEGUE_END_POINT=-1,\
+                           TALK_START_POINT=-1,TALK_END_POINT=-1,\
+                           HOOK_START_POINT=-1,HOOK_END_POINT=-1,\
+                           PLAY_GAIN=0,LENGTH=%d \
+                           where CUT_NAME=\"%s\"",
+			  len,len,(const char *)cutname);
+    q=new QSqlQuery(sql);
+    delete q;
+    cart->updateLength();
+    cart->resetRotation();
+  }
+  delete cart;
+  delete cut;
+}
+
+
 void MainObject::CleanTables(const QString &ext,QSqlQuery *table_q,
 			     QSqlQuery *name_q)
 {
